@@ -152,7 +152,7 @@ Genezzo::Contrib::Clustered::GLock::GLock - Generic locking for Genezzo
 =head1 SYNOPSIS
 
     $curLock = new GLock(lock => $lockName, block => 1);
-    $curLock->lock(shared => $shared);
+    $curLock->lock(shared => 0);
     $curLock->promote();
     $curLock->unlock();
 
@@ -184,8 +184,6 @@ Unlocks lock.
 
 =back
 
-=head2 EXPORT
-
 =head1 LIMITATIONS
 
 Edit $IMPL to choose implementation.  This will eventually be configured
